pub fn divide_function(
parameters: &[String],
_context: &mut Context,
) -> Result<String, SyntaxError>Expand description
Divides values. If any of the parameters is not convertible to a number, then an error will be emitted with the invalid value.
Eg.
/ 1440 8 6 4Expected output:
7.5