minus_function

Function minus_function 

pub fn minus_function(
    parameters: &[String],
    _context: &mut Context,
) -> Result<String, SyntaxError>
Subtracts values. If any of the parameters is not convertible to a number, then an error will be emitted with the invalid value.

Eg.

- 8.3 1 1.4

Expected output:

5.9