pub fn modulo_function(
parameters: &[String],
_context: &mut Context,
) -> Result<String, SyntaxError>Expand description
Calculates the remainder (modulo). If any of the parameters is not convertible to a number, then an error will be emitted with the invalid value.
Eg.
mod 7 4Expected output:
3